gui Package
===========

:mod:`gui` Package
------------------

.. automodule:: hyperspy.gui
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`eels` Module
------------------

.. automodule:: hyperspy.gui.eels
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`egerton_quantification` Module
------------------------------------

.. automodule:: hyperspy.gui.egerton_quantification
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`main_window` Module
-------------------------

.. automodule:: hyperspy.gui.main_window
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`messages` Module
----------------------

.. automodule:: hyperspy.gui.messages
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`mpl_traits_editor` Module
-------------------------------

.. automodule:: hyperspy.gui.mpl_traits_editor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`tools` Module
-------------------

.. automodule:: hyperspy.gui.tools
    :members:
    :undoc-members:
    :show-inheritance:

